##############
Risk Functions
##############

.. raw:: html

    <a href='https://ko-fi.com/B0B833SXD' target='_blank'><img height='36'style='border:0px;height:36px;' src='https://cdn.ko-fi.com/cdn/kofi1.png?v=2' border='0' alt='Buy Me a Coffee at ko-fi.com' /></a>

This module has functions that calculates several risk measures that are
widely used by the asset management industry and academics.


Module Functions
================

.. automodule:: RiskFunctions
   :members:
   :private-members:
